@@ -30,36 +30,37 @@ class File:
         if file_type in ['xlsx', 'xls']:
             data = xlrd.open_workbook(url)
             return data.sheet_by_name(sheet_name)
-
+        to_string = kwargs.get('to_string')
         f = open(url, read_type)
         text = f.read()
         f.close()
-        if file_type in ['csv', 'tsv'] or 'sep' in kwargs:
-            encoding = chardet.detect(text)['encoding']
-            sep = ',' if file_type == 'csv' else '\t'
-            if 'sep' in kwargs:
-                sep = kwargs['sep']
-            delimiter = {'delimiter': sep}
-            f = open(url, read_type)
-            # csv.register_dialect('my_dialect', **delimiter)
-            cons = csv.reader(f, **delimiter)
-            items = []
-            keys = next(cons)
-            for c in cons:
-                if to_json:
-                    item = {}
-                    for i in range(len(keys)):
-                        k = keys[i].decode(encoding).encode('utf-8')
-                        item[k] = c[i].decode(encoding).encode('utf-8')
-                    items.append(item)
-                else:
-                    items.append([x.decode(encoding).encode('utf-8') for x in c])
-            # csv.unregister_dialect('my_dialect')
-            if to_json is False:
-                items = [keys] + items
-            return items
-        if file_type == 'json':
-            return json.loads(text)
+        if not to_string:
+            if file_type in ['csv', 'tsv'] or 'sep' in kwargs:
+                encoding = chardet.detect(text)['encoding']
+                sep = ',' if file_type == 'csv' else '\t'
+                if 'sep' in kwargs:
+                    sep = kwargs['sep']
+                delimiter = {'delimiter': sep}
+                f = open(url, read_type)
+                # csv.register_dialect('my_dialect', **delimiter)
+                cons = csv.reader(f, **delimiter)
+                items = []
+                keys = next(cons)
+                for c in cons:
+                    if to_json:
+                        item = {}
+                        for i in range(len(keys)):
+                            k = keys[i].decode(encoding).encode('utf-8')
+                            item[k] = c[i].decode(encoding).encode('utf-8')
+                        items.append(item)
+                    else:
+                        items.append([x.decode(encoding).encode('utf-8') for x in c])
+                # csv.unregister_dialect('my_dialect')
+                if to_json is False:
+                    items = [keys] + items
+                return items
+            if file_type == 'json':
+                return json.loads(text)
         return text
 
     def read_message(self, file_name, file_type='json', sheet_name='', read_type='r', developer='huohuo', message='success'):
